# Block Title HTML Element

A Drupal module that allows administrators to choose the HTML element used for block titles through the block configuration interface.

## Features

- **Security-focused**: Only allows safe, semantic HTML elements
- **User-friendly interface**: Dropdown selector with element descriptions
- **Flexible**: Works with any block type in Drupal
- **Performance optimized**: Minimal overhead with proper caching
- **Drupal 11 compatible**: Full support for latest Drupal versions

## Supported HTML Elements

The module supports the following safe HTML elements:

- **Headings**: h2, h3, h4, h5, h6
- **Text containers**: span, p
- **Text formatting**: em, b, i

Note: h1 is intentionally excluded to maintain proper document hierarchy and SEO best practices.

## Installation

1. Download and extract the module to your `modules/contrib` directory
2. Enable the module: `drush en block_title_html_element`
3. Grant the "Administer block title element" permission to appropriate roles

## Usage

### In Block Configuration

1. Navigate to **Administration > Structure > Block Layout**
2. Click **Configure** on any block
3. Open the **Block Title HTML Element** section
4. Select your desired HTML element from the dropdown
5. Save the block configuration

### In Twig Templates

Update your `block.html.twig` template to use the dynamic element:

```twig
{% if label %}
  <{{ title_element | default('strong') }}{{ title_attributes.addClass('block-title') }}>
    {{ label }}
  </{{ title_element | default('strong') }}>
{% endif %}
```

### Default Behavior

- If no element is selected, defaults to `strong`
- Invalid elements are automatically filtered for security
- Works with all block types including custom blocks

## Requirements

- **PHP**: 8.1 or higher
- **Drupal**: 9.5, 10.x, or 11.x
- **Permissions**: Users need "Administer block title element" permission

## Security

This module implements several security measures:

- **Allowlist approach**: Only predefined safe HTML elements are permitted
- **Input validation**: All user input is validated against the allowlist
- **XSS prevention**: No arbitrary HTML or script injection possible
- **Runtime validation**: Elements are validated during both save and render

## Troubleshooting

### Element not appearing
- Ensure you've updated your `block.html.twig` template
- Clear caches after making changes
- Verify the user has proper permissions

### Security warnings
- The module will automatically reset invalid elements to default
- Check logs for any validation warnings
- Only use elements from the approved list

## Development

### Extending Allowed Elements

To add custom elements, you can alter the allowed elements array:

```php
/**
 * Implements hook_block_title_html_element_allowed_elements_alter().
 */
function mymodule_block_title_html_element_allowed_elements_alter(&$elements) {
  $elements['article'] = t('Article');
}
```

## License

GPL-2.0-or-later