<?php

namespace Drupal\block_title_html_element\Service;

use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Service for validating and managing allowed HTML elements.
 */
class ElementValidator {

  use StringTranslationTrait;

  /**
   * The module handler service.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * Constructs an ElementValidator object.
   *
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler service.
   */
  public function __construct(ModuleHandlerInterface $module_handler) {
    $this->moduleHandler = $module_handler;
  }

  /**
   * Get allowed HTML elements for block titles.
   *
   * @return array
   *   An array of allowed HTML elements with labels.
   */
  public function getAllowedElements(): array {
    $elements = [
      'h2' => $this->t('Heading 2 (h2)'),
      'h3' => $this->t('Heading 3 (h3)'),
      'h4' => $this->t('Heading 4 (h4)'),
      'h5' => $this->t('Heading 5 (h5)'),
      'h6' => $this->t('Heading 6 (h6)'),
      'span' => $this->t('Span'),
      'p' => $this->t('Paragraph (p)'),
      'em' => $this->t('Emphasis (em)'),
      'b' => $this->t('Bold (b)'),
      'i' => $this->t('Italic (i)'),
    ];

    // Allow other modules to alter the allowed elements.
    $this->moduleHandler->alter('block_title_html_element_allowed_elements', $elements);

    return $elements;
  }

  /**
   * Validate HTML element input.
   *
   * @param string $element
   *   The HTML element to validate.
   *
   * @return bool
   *   TRUE if valid, FALSE otherwise.
   */
  public function validateElement(string $element): bool {
    $allowed_elements = array_keys($this->getAllowedElements());
    return in_array($element, $allowed_elements, TRUE);
  }

} 